# generated by fastapi-codegen:
#   filename:  /home/circleci/project/guardicore/connector
#   timestamp: 2025-08-06T07:59:35+00:00

from __future__ import annotations

from enum import Enum
from typing import Optional
from uuid import UUID

from pydantic import BaseModel, ConfigDict, conint


class LogStart(BaseModel):
    model_config = ConfigDict(
        populate_by_name=True,
    )
    id: UUID
    max_size: Optional[conint(ge=0, le=5242880)] = None
    rotated_logs: Optional[bool] = False
    local_config: Optional[bool] = True


class Status(Enum):
    NOT_STARTED = 'not_started'
    STARTED = 'started'
    DONE = 'done'
    FAILED = 'failed'


class LogStatus(BaseModel):
    model_config = ConfigDict(
        populate_by_name=True,
    )
    status: Status
