# generated by fastapi-codegen:
#   filename:  /home/circleci/project/guardicore/connector
#   timestamp: 2025-08-06T07:59:35+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, ConfigDict, Field


class VersionHandshakeData(BaseModel):
    model_config = ConfigDict(
        populate_by_name=True,
    )
    version: Optional[str] = Field(
        None, description='The version of the endpoint system'
    )
    contract_version: Optional[str] = Field(
        None,
        alias='contract-version',
        description='The latest supported contract version in use by the endpoint i.e 4.2.1',
    )
    component_id: Optional[str] = Field(
        None,
        alias='component-id',
        description='The identifier of the cloud-app/centra system',
    )
