# generated by fastapi-codegen:
#   filename:  /home/circleci/project/guardicore/connector
#   timestamp: 2025-08-06T07:59:35+00:00

from __future__ import annotations

from typing import List, Optional

from pydantic import BaseModel, ConfigDict, Field


class AgentsInfo(BaseModel):
    model_config = ConfigDict(
        populate_by_name=True,
    )
    mac_addresses: Optional[List[str]] = Field(
        None,
        alias='mac-addresses',
        description='Known agents MAC addresses without separator',
        examples=[['000000000000', '112233445566']],
    )
