# generated by fastapi-codegen:
#   filename:  /home/circleci/project/guardicore/connector
#   timestamp: 2025-08-06T07:59:35+00:00

from __future__ import annotations

from enum import Enum


class Connector(Enum):
    CLOUD_AZURE = 'cloud_azure'
    CLOUD_AWS = 'cloud_aws'
    PACKETFENCE = 'packetfence'
    ALGOSEC = 'algosec'
    PENSANDO = 'pensando'
